@@ -38,7 +38,7 @@ except ImportError, ex:
 from gamera import __version__ as version
 from gamera.core import load_image as _load_image
 from gamera.core import init_gamera as _init
-from gamera.core import Image, RGB, GREYSCALE, ONEBIT, Dim, RGBPixel
+from gamera.core import Image, RGB, GREYSCALE, ONEBIT, Point, Dim, RGBPixel
 from gamera.plugins.pil_io import from_pil as _from_pil
 
 def has_version(*req_version):
@@ -147,7 +147,7 @@ def init():
     test_string = test_image._to_raw_string()
     refcount = sys.getrefcount(test_string)
     if refcount == 3:
-        # See: http://tech.groups.yahoo.com/group/gamera-devel/message/2068
+        # See: https://tech.groups.yahoo.com/group/gamera-devel/message/2068
         warnings.warn(RuntimeWarning('Working around memory leak in the Gamera library'), stacklevel=2)
         _monkeypatch_to_raw_string()
         fixed_test_string = test_image._to_raw_string()
